# Copyright 2017 Red Hat, Inc
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.
__all__ = ['read_data']

import json
import os

DATA_DIR = os.path.dirname(__file__)


def read_data(filename):
    """Return data that is shipped inside the Python package.

    """

    filepath = os.path.join(DATA_DIR, filename)
    with open(filepath, 'r') as fd:
        return json.load(fd)
